// -*- C++ -*-
/* This file is part of
 * ======================================================
 * 
 *           LyX, The Document Processor
 * 	 
 *	    Copyright (C) 1995 Matthias Ettrich
 *          Copyright (C) 1995-1999 The LyX Team.
 *
 * ====================================================== */


#ifndef LISTREAM_H
#define LISTREAM_H 

#ifdef HAVE_ISTREAM
#include <istream>
#else 
#include <iostream>
#endif

using std::istream;

#endif
